@@ -18,7 +18,7 @@ impl<T> StatefulList<T> {
   }
 
   pub fn next(&mut self) {
-    if self.items.len() == 0 {
+    if self.items.is_empty() {
       return;
     }
     let i = match self.state.selected() {
@@ -35,7 +35,7 @@ impl<T> StatefulList<T> {
   }
 
   pub fn previous(&mut self) {
-    if self.items.len() == 0 {
+    if self.items.is_empty() {
       return;
     }
     let i = match self.state.selected() {
@@ -51,7 +51,7 @@ impl<T> StatefulList<T> {
     self.state.select(Some(i));
   }
 
-  pub fn unselect(&mut self) {
-    self.state.select(None);
-  }
+  // pub fn unselect(&mut self) {
+  //   self.state.select(None);
+  // }
 }
