@@ -13,7 +13,8 @@ use crate::{
     traits::key::{Key, KeyHash, Keyed},
     with_key::datasample::DataSample,
   },
-  structure::{guid::GUID, time::Timestamp},
+  structure::{guid::GUID, sequence_number::SequenceNumber, time::Timestamp},
+  with_key::WriteOptions,
 };
 
 //use std::num::Zero; unstable
@@ -55,11 +56,10 @@ struct SampleWithMetaData<D: Keyed> {
   // a snapshot of the instance-wide counts
   // at the time this sample was received.
   generation_counts: NotAliveGenerationCounts,
-  // who wrote this
-  writer_guid: GUID,
-  // timestamps
-  source_timestamp: Option<Timestamp>, // as stamped by sender
-  sample_has_been_read: bool,          // sample_state
+  writer_guid: GUID,               // who wrote this
+  sequence_number: SequenceNumber, // as sent by the Writer
+  write_options: WriteOptions,     // as stamped by Writer
+  sample_has_been_read: bool,      // sample_state
 
   // the data sample (or key) itself is stored here
   sample: Result<D, D::K>,
@@ -96,8 +96,9 @@ where
     &mut self,
     new_sample: Result<D, D::K>,
     writer_guid: GUID,
+    sequence_number: SequenceNumber,
     receive_timestamp: Timestamp,
-    source_timestamp: Option<Timestamp>,
+    write_options: WriteOptions,
   ) {
     let instance_key = match &new_sample {
       Ok(d) => d.key(),
@@ -168,7 +169,8 @@ where
         SampleWithMetaData {
           generation_counts: instance_metadata.latest_generation_available,
           writer_guid,
-          source_timestamp,
+          sequence_number,
+          write_options,
           sample_has_been_read: false,
           sample: new_sample,
         },
@@ -318,8 +320,9 @@ where
       sample_rank: sample_rank as i32, // how many samples follow this one
       generation_rank: mrsic_generations - dswm.generation_counts.total(),
       absolute_generation_rank: mrs_generations - dswm.generation_counts.total(),
-      source_timestamp: dswm.source_timestamp,
+      write_options: dswm.write_options.clone(),
       publication_handle: dswm.writer_guid,
+      sequence_number: dswm.sequence_number,
     }
   }
 
