@@ -37,11 +37,11 @@ use super::dp_event_loop::DomainInfo;
 /// some memory for object caches.
 ///
 /// If you need to communicate to many DDS domains,
-/// then you must create a separate DomainParticiapnt for each of them.
+/// then you must create a separate DomainParticipant for each of them.
 /// See DDS Spec v1.4 Section "2.2.1.2.2 Overall Conceptual Model" and
 /// "2.2.2.2.1 DomainParticipant Class" for a definition of a (DDS) domain.
 /// Domains are identified by a domain identifier, which is, in Rust terms, a
-/// `u16`. Domain identifer values are application-specific, but `0` is usually
+/// `u16`. Domain identifier values are application-specific, but `0` is usually
 /// the default.
 #[derive(Clone)]
 // This is a smart pointer for DomainParticipantInner for easier manipulation.
@@ -54,6 +54,7 @@ impl DomainParticipant {
   /// # Examples
   /// ```
   /// # use rustdds::DomainParticipant;
+  ///
   /// let domain_participant = DomainParticipant::new(0).unwrap();
   /// ```
   pub fn new(domain_id: u16) -> Result<DomainParticipant> {
@@ -147,8 +148,8 @@ impl DomainParticipant {
   /// # Examples
   ///
   /// ```
-  /// # use rustdds::dds::DomainParticipant;
-  /// # use rustdds::dds::qos::QosPolicyBuilder;
+  /// # use rustdds::{DomainParticipant, QosPolicyBuilder};
+  ///
   /// let domain_participant = DomainParticipant::new(0).unwrap();
   /// let qos = QosPolicyBuilder::new().build();
   /// let publisher = domain_participant.create_publisher(&qos);
@@ -168,8 +169,8 @@ impl DomainParticipant {
   /// # Examples
   ///
   /// ```
-  /// # use rustdds::dds::DomainParticipant;
-  /// # use rustdds::dds::qos::QosPolicyBuilder;
+  /// # use rustdds::{DomainParticipant, QosPolicyBuilder};
+  ///
   /// let domain_participant = DomainParticipant::new(0).unwrap();
   /// let qos = QosPolicyBuilder::new().build();
   /// let subscriber = domain_participant.create_subscriber(&qos);
@@ -192,9 +193,7 @@ impl DomainParticipant {
   /// # Examples
   ///
   /// ```
-  /// # use rustdds::dds::DomainParticipant;
-  /// # use rustdds::dds::qos::QosPolicyBuilder;
-  /// use rustdds::dds::data_types::TopicKind;
+  /// # use rustdds::{DomainParticipant, TopicKind, QosPolicyBuilder};
   ///
   /// let domain_participant = DomainParticipant::new(0).unwrap();
   /// let qos = QosPolicyBuilder::new().build();
@@ -224,7 +223,8 @@ impl DomainParticipant {
   /// # Examples
   ///
   /// ```
-  /// # use rustdds::dds::DomainParticipant;
+  /// # use rustdds::DomainParticipant;
+  ///
   /// let domain_participant = DomainParticipant::new(0).unwrap();
   /// let domain_id = domain_participant.domain_id();
   /// ```
@@ -235,7 +235,8 @@ impl DomainParticipant {
   /// # Examples
   ///
   /// ```
-  /// # use rustdds::dds::DomainParticipant;
+  /// # use rustdds::DomainParticipant;
+  ///
   /// let domain_participant = DomainParticipant::new(0).unwrap();
   /// let participant_id = domain_participant.participant_id();
   /// ```
@@ -248,7 +249,8 @@ impl DomainParticipant {
   /// # Examples
   ///
   /// ```
-  /// # use rustdds::dds::DomainParticipant;
+  /// # use rustdds::DomainParticipant;
+  ///
   /// let domain_participant = DomainParticipant::new(0).unwrap();
   /// let discovered_topics = domain_participant.discovered_topics();
   /// for dtopic in discovered_topics.iter() {
@@ -266,7 +268,8 @@ impl DomainParticipant {
   /// # Example
   ///
   /// ```
-  /// # use rustdds::dds::DomainParticipant;
+  /// # use rustdds::DomainParticipant;
+  ///
   /// let domain_participant = DomainParticipant::new(0).expect("Failed to create participant");
   /// domain_participant.assert_liveliness();
   /// ```
@@ -327,17 +330,19 @@ impl DomainParticipantWeak {
   }
 
   pub fn create_publisher(&self, qos: &QosPolicies) -> Result<Publisher> {
-    match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().create_publisher(self, qos),
-      None => Err(Error::OutOfResources),
-    }
+    self
+      .dpi
+      .upgrade()
+      .ok_or(Error::OutOfResources)
+      .and_then(|dpi| dpi.lock().unwrap().create_publisher(self, qos))
   }
 
   pub fn create_subscriber(&self, qos: &QosPolicies) -> Result<Subscriber> {
-    match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().create_subscriber(self, qos),
-      None => Err(Error::OutOfResources),
-    }
+    self
+      .dpi
+      .upgrade()
+      .ok_or(Error::OutOfResources)
+      .and_then(|dpi| dpi.lock().unwrap().create_subscriber(self, qos))
   }
 
   pub fn create_topic(
@@ -347,42 +352,53 @@ impl DomainParticipantWeak {
     qos: &QosPolicies,
     topic_kind: TopicKind,
   ) -> Result<Topic> {
-    match self.dpi.upgrade() {
-      Some(dpi) => dpi
-        .lock()
-        .unwrap()
-        .create_topic(self, name, type_desc, qos, topic_kind),
-      None => Err(Error::LockPoisoned),
-    }
+    self
+      .dpi
+      .upgrade()
+      .ok_or(Error::LockPoisoned)
+      .and_then(|dpi| {
+        dpi
+          .lock()
+          .unwrap()
+          .create_topic(self, name, type_desc, qos, topic_kind)
+      })
   }
 
-  pub fn find_topic(&self, name: &str, timeout: Duration) -> Result<Option<Topic>> {
-    match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().find_topic(self, name, timeout),
-      None => Err(Error::LockPoisoned),
-    }
-  }
+  // pub fn find_topic(&self, name: &str, timeout: Duration) ->
+  // Result<Option<Topic>> {   self
+  //     .dpi
+  //     .upgrade()
+  //     .ok_or(Error::LockPoisoned)
+  //     .and_then(|dpi| dpi.lock().unwrap().find_topic(self, name, timeout))
+  // }
 
-  pub fn domain_id(&self) -> u16 {
-    match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().domain_id(),
-      None => panic!("Unable to get original domain participant."),
-    }
-  }
+  // pub fn domain_id(&self) -> u16 {
+  //   self
+  //     .dpi
+  //     .upgrade()
+  //     .expect("Unable to get original domain participant.")
+  //     .lock()
+  //     .unwrap()
+  //     .domain_id()
+  // }
 
-  pub fn participant_id(&self) -> u16 {
-    match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().participant_id(),
-      None => panic!("Unable to get original domain participant."),
-    }
-  }
+  // pub fn participant_id(&self) -> u16 {
+  //   self
+  //     .dpi
+  //     .upgrade()
+  //     .expect("Unable to get original domain participant.")
+  //     .lock()
+  //     .unwrap()
+  //     .participant_id()
+  // }
 
-  pub fn discovered_topics(&self) -> Vec<DiscoveredTopicData> {
-    match self.dpi.upgrade() {
-      Some(dpi) => dpi.lock().unwrap().discovered_topics(),
-      None => Vec::new(),
-    }
-  }
+  // pub fn discovered_topics(&self) -> Vec<DiscoveredTopicData> {
+  //   self
+  //     .dpi
+  //     .upgrade()
+  //     .map(|dpi| dpi.lock().unwrap().discovered_topics())
+  //     .unwrap_or_default()
+  // }
 
   pub fn upgrade(self) -> Option<DomainParticipant> {
     self.dpi.upgrade().map(|d| DomainParticipant { dpi: d })
@@ -503,9 +519,9 @@ impl DomainParticipantDisc {
     self.dpi.lock().unwrap().dds_cache()
   }
 
-  pub(crate) fn discovery_db(&self) -> Arc<RwLock<DiscoveryDB>> {
-    self.dpi.lock().unwrap().discovery_db.clone()
-  }
+  // pub(crate) fn discovery_db(&self) -> Arc<RwLock<DiscoveryDB>> {
+  //   self.dpi.lock().unwrap().discovery_db.clone()
+  // }
 
   pub(crate) fn assert_liveliness(&self) -> Result<()> {
     // No point in checking for the LIVELINESS QoS of MANUAL_BY_PARTICIPANT,
@@ -555,10 +571,6 @@ pub(crate) struct DomainParticipantInner {
   sender_add_reader: mio_channel::SyncSender<ReaderIngredients>,
   sender_remove_reader: mio_channel::SyncSender<GUID>,
 
-  // Adding DataReaders
-  sender_add_datareader_vec: Vec<mio_channel::SyncSender<()>>,
-  sender_remove_datareader_vec: Vec<mio_channel::SyncSender<GUID>>,
-
   // dp_event_loop control
   stop_poll_sender: mio_channel::Sender<()>,
   ev_loop_handle: Option<JoinHandle<()>>, // this is Option, because it needs to be extracted
@@ -638,7 +650,7 @@ impl DomainParticipantInner {
 
     info!("ParticipantId {} selected.", participant_id);
 
-    // here discovery_listener is redefinde (shadowed)
+    // here discovery_listener is redefined (shadowed)
     let discovery_listener = match discovery_listener {
       Some(dl) => dl,
       None => return log_and_err_internal!("Could not find free ParticipantId"),
@@ -658,30 +670,25 @@ impl DomainParticipantInner {
       Err(e) => warn!("Cannot get multicast user traffic listener: {:?}", e),
     }
 
-    let user_traffic_listener = match UDPListener::new_unicast(
+    let user_traffic_listener = UDPListener::new_unicast(
       "0.0.0.0",
       user_traffic_unicast_port(domain_id, participant_id),
-    ) {
-      Ok(l) => l,
-      Err(e) => match e.kind() {
-        ErrorKind::AddrInUse => {
-          // If we do not get the proferred listening port,
-          // try again, with "any" port number.
-          match UDPListener::new_unicast("0.0.0.0", 0) {
-            Ok(l) => l,
-            Err(e) => {
-              return log_and_err_internal!(
-                "Could not open unicast user traffic listener, any port number: {:?}",
-                e
-              )
-            }
-          }
-        }
-        _other_kind => {
-          return log_and_err_internal!("Could not open unicast user traffic listener: {:?}", e)
-        }
-      },
-    };
+    )
+    .or_else(|e| {
+      if matches!(e.kind(), ErrorKind::AddrInUse) {
+        // If we do not get the preferred listening port,
+        // try again, with "any" port number.
+        UDPListener::new_unicast("0.0.0.0", 0).or_else(|e| {
+          log_and_err_internal!(
+            "Could not open unicast user traffic listener, any port number: {:?}",
+            e
+          )
+        })
+      } else {
+        log_and_err_internal!("Could not open unicast user traffic listener: {:?}", e)
+      }
+    })?;
+
     listeners.insert(USER_TRAFFIC_LISTENER_TOKEN, user_traffic_listener);
 
     // construct our own Locators
@@ -735,7 +742,7 @@ impl DomainParticipantInner {
           listeners,
           dds_cache_clone,
           disc_db_clone,
-          new_guid.guid_prefix,
+          new_guid.prefix,
           TokenReceiverPair {
             token: ADD_READER_TOKEN,
             receiver: receiver_add_reader,
@@ -767,12 +774,8 @@ impl DomainParticipantInner {
       domain_id,
       participant_id,
       my_guid: new_guid,
-      // Adding readers
       sender_add_reader,
       sender_remove_reader,
-      // Adding datareaders
-      sender_add_datareader_vec: Vec::new(),
-      sender_remove_datareader_vec: Vec::new(),
       stop_poll_sender,
       ev_loop_handle: Some(ev_loop_handle),
       add_writer_sender,
@@ -788,14 +791,14 @@ impl DomainParticipantInner {
     self.dds_cache.clone()
   }
 
-  pub fn add_reader(&self, reader: ReaderIngredients) {
-    self.sender_add_reader.send(reader).unwrap();
-  }
+  // pub fn add_reader(&self, reader: ReaderIngredients) {
+  //   self.sender_add_reader.send(reader).unwrap();
+  // }
 
-  pub fn remove_reader(&self, guid: GUID) {
-    let reader_guid = guid; // How to identify reader to be removed?
-    self.sender_remove_reader.send(reader_guid).unwrap();
-  }
+  // pub fn remove_reader(&self, guid: GUID) {
+  //   let reader_guid = guid; // How to identify reader to be removed?
+  //   self.sender_remove_reader.send(reader_guid).unwrap();
+  // }
 
   // Publisher and subscriber creation
   //
@@ -814,6 +817,7 @@ impl DomainParticipantInner {
       qos.clone(),
       qos.clone(),
       self.add_writer_sender.clone(),
+      self.remove_writer_sender.clone(),
       discovery_command,
     ))
   }
@@ -836,7 +840,7 @@ impl DomainParticipantInner {
 
   // Topic creation. Data types should be handled as something (potentially) more
   // structured than a String. NOTE: Here we are using &str for topic name. &str
-  // is Unicode string, whereas DDS specifes topic name to be a sequence of
+  // is Unicode string, whereas DDS specifies topic name to be a sequence of
   // octets, which would be &[u8] in Rust. This may cause problems if there are
   // topic names with non-ASCII characters. On the other hand, string handling
   // with &str is easier in Rust.
@@ -860,7 +864,7 @@ impl DomainParticipantInner {
     // TODO: refine
   }
 
-  // Do not implement contentfilteredtopics or multitopics (yet)
+  // Do not implement content filtered topics or multi-topics (yet)
 
   pub fn find_topic(
     &self,
@@ -906,10 +910,7 @@ impl DomainParticipantInner {
     domain_participant_weak: &DomainParticipantWeak,
     name: &str,
   ) -> Result<Option<Topic>> {
-    let db = match self.discovery_db.read() {
-      Ok(db) => db,
-      Err(_) => return Err(Error::LockPoisoned),
-    };
+    let db = self.discovery_db.read().map_err(|_| Error::LockPoisoned)?;
 
     let build_topic_fn = |d: &DiscoveredTopicData| {
       let qos = d.topic_data.qos();
@@ -931,29 +932,29 @@ impl DomainParticipantInner {
   }
   // get_builtin_subscriber (why would we need this?)
 
-  // ignore_* operations. TODO: Do we needa any of those?
+  // ignore_* operations. TODO: Do we need any of those?
 
-  // delete_contained_entities is not needed. Data structures shoud be designed so
-  // that lifetime of all created objects is within the lifetime of
+  // delete_contained_entities is not needed. Data structures should be designed
+  // so that lifetime of all created objects is within the lifetime of
   // DomainParticipant. Then such deletion is implicit.
 
   // The following methods are not for application use.
 
-  pub(crate) fn get_add_reader_sender(&self) -> mio_channel::SyncSender<ReaderIngredients> {
-    self.sender_add_reader.clone()
-  }
+  // pub(crate) fn get_add_reader_sender(&self) ->
+  // mio_channel::SyncSender<ReaderIngredients> {   self.sender_add_reader.
+  // clone() }
 
-  pub(crate) fn get_remove_reader_sender(&self) -> mio_channel::SyncSender<GUID> {
-    self.sender_remove_reader.clone()
-  }
+  // pub(crate) fn get_remove_reader_sender(&self) ->
+  // mio_channel::SyncSender<GUID> {   self.sender_remove_reader.clone()
+  // }
 
-  pub(crate) fn get_add_writer_sender(&self) -> mio_channel::SyncSender<WriterIngredients> {
-    self.add_writer_sender.clone()
-  }
+  // pub(crate) fn get_add_writer_sender(&self) ->
+  // mio_channel::SyncSender<WriterIngredients> {   self.add_writer_sender.
+  // clone() }
 
-  pub(crate) fn get_remove_writer_sender(&self) -> mio_channel::SyncSender<GUID> {
-    self.remove_writer_sender.clone()
-  }
+  // pub(crate) fn get_remove_writer_sender(&self) ->
+  // mio_channel::SyncSender<GUID> {   self.remove_writer_sender.clone()
+  // }
 
   pub fn domain_id(&self) -> u16 {
     self.domain_id
@@ -964,10 +965,10 @@ impl DomainParticipantInner {
   }
 
   pub fn discovered_topics(&self) -> Vec<DiscoveredTopicData> {
-    let db = match self.discovery_db.read() {
-      Ok(db) => db,
-      Err(e) => panic!("DiscoveryDB is poisoned. {:?}", e),
-    };
+    let db = self
+      .discovery_db
+      .read()
+      .unwrap_or_else(|e| panic!("DiscoveryDB is poisoned. {:?}", e));
 
     db.all_topics().cloned().collect()
   }
@@ -1045,7 +1046,7 @@ mod tests {
     // TODO: get result data from Reader
   }
   #[test]
-  fn dp_writer_hearbeat_test() {
+  fn dp_writer_heartbeat_test() {
     let domain_participant = DomainParticipant::new(0).expect("Participant creation failed!");
     let qos = QosPolicies::qos_none();
     let _default_dw_qos = QosPolicies::qos_none();
@@ -1120,7 +1121,7 @@ mod tests {
       protocol_id: ProtocolId::default(),
       protocol_version: ProtocolVersion { major: 2, minor: 3 },
       vendor_id: VendorId::THIS_IMPLEMENTATION,
-      guid_prefix: GUID::default().guid_prefix,
+      guid_prefix: GUID::default().prefix,
     };
     m.set_header(h);
     m.add_submessage(s);
