@@ -706,7 +706,7 @@ where
       CacheChange {
         writer_guid,
         sequence_number,
-        source_timestamp,
+        write_options,
         data_value,
       },
     ) in cache_changes_vec
@@ -750,8 +750,9 @@ where
                 Ok(payload) => self.datasample_cache.add_sample(
                   Ok(payload),
                   *writer_guid,
+                  *sequence_number,
                   instant,
-                  *source_timestamp,
+                  write_options.clone(),
                 ),
                 Err(e) => {
                   error!(
@@ -760,7 +761,7 @@ where
                     self.my_topic.name(),
                     self.my_topic.get_type()
                   );
-                  debug!("Bytes were {:?}", &serialized_payload.value);
+                  info!("Bytes were {:?}", &serialized_payload.value);
                   continue; // skip this sample
                 }
               }
@@ -769,7 +770,7 @@ where
                 "Unknown representation id {:?}.",
                 serialized_payload.representation_identifier
               );
-              debug!("Serialized payload was {:?}", &serialized_payload);
+              info!("Serialized payload was {:?}", &serialized_payload);
               continue; // skip this sample, as we cannot decode it
             }
           }
@@ -787,8 +788,9 @@ where
                 self.datasample_cache.add_sample(
                   Err(key),
                   *writer_guid,
+                  *sequence_number,
                   instant,
-                  *source_timestamp,
+                  write_options.clone(),
                 );
               }
               Err(e) => {
@@ -808,9 +810,13 @@ where
             /* TODO: Instance to be disposed could be specified by serialized payload
              * also, not only key_hash? */
             if let Some(key) = self.datasample_cache.key_by_hash(*key_hash) {
-              self
-                .datasample_cache
-                .add_sample(Err(key), *writer_guid, instant, *source_timestamp);
+              self.datasample_cache.add_sample(
+                Err(key),
+                *writer_guid,
+                *sequence_number,
+                instant,
+                write_options.clone(),
+              );
             } else {
               warn!("Tried to dispose with unkonwn key hash: {:x?}", key_hash);
             }
