@@ -1,6 +1,9 @@
 use std::{
   marker::PhantomData,
-  sync::{Arc, RwLock},
+  sync::{
+    atomic::{AtomicI64, Ordering},
+    Arc, RwLock,
+  },
   time::Duration,
 };
 
@@ -31,12 +34,77 @@ use crate::{
   messages::submessages::submessage_elements::serialized_payload::SerializedPayload,
   serialization::CDRSerializerAdapter,
   structure::{
-    cache_change::ChangeKind, dds_cache::DDSCache, entity::RTPSEntity, guid::GUID, time::Timestamp,
-    topic_kind::TopicKind,
+    cache_change::ChangeKind, dds_cache::DDSCache, entity::RTPSEntity, guid::GUID,
+    rpc::SampleIdentity, sequence_number::SequenceNumber, time::Timestamp, topic_kind::TopicKind,
   },
 };
 use super::super::writer::WriterCommand;
 
+// It is a bit overkill to use a builder for such a simple struct, but
+// it may be expanded in future versions of RustDDS or even the spec.
+// TODO: Move the write options and the builder type to some lower-level module
+// to avoid circular dependencies.
+#[derive(Debug, Default)]
+pub struct WriteOptionsBuilder {
+  related_sample_identity: Option<SampleIdentity>,
+  source_timestamp: Option<Timestamp>,
+}
+
+impl WriteOptionsBuilder {
+  pub fn new() -> WriteOptionsBuilder {
+    WriteOptionsBuilder::default()
+  }
+
+  pub fn build(self) -> WriteOptions {
+    WriteOptions {
+      related_sample_identity: self.related_sample_identity,
+      source_timestamp: self.source_timestamp,
+    }
+  }
+
+  #[must_use]
+  pub fn related_sample_identity(
+    mut self,
+    related_sample_identity: SampleIdentity,
+  ) -> WriteOptionsBuilder {
+    self.related_sample_identity = Some(related_sample_identity);
+    self
+  }
+
+  #[must_use]
+  pub fn related_sample_identity_opt(
+    mut self,
+    related_sample_identity_opt: Option<SampleIdentity>,
+  ) -> WriteOptionsBuilder {
+    self.related_sample_identity = related_sample_identity_opt;
+    self
+  }
+
+  #[must_use]
+  pub fn source_timestamp(mut self, source_timestamp: Timestamp) -> WriteOptionsBuilder {
+    self.source_timestamp = Some(source_timestamp);
+    self
+  }
+}
+
+/// Type to be used with write_with_options.
+/// Use WriteOptionsBuilder to construct this.
+#[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Debug, Default)]
+pub struct WriteOptions {
+  pub(crate) related_sample_identity: Option<SampleIdentity>,
+  pub(crate) source_timestamp: Option<Timestamp>,
+  // future extension room fo other fields.
+}
+
+impl From<Option<Timestamp>> for WriteOptions {
+  fn from(source_timestamp: Option<Timestamp>) -> WriteOptions {
+    WriteOptions {
+      related_sample_identity: None,
+      source_timestamp,
+    }
+  }
+}
+
 /// Simplified type for CDR encoding
 pub type DataWriterCdr<D> = DataWriter<D, CDRSerializerAdapter<D>>;
 
@@ -81,6 +149,7 @@ pub struct DataWriter<D: Keyed + Serialize, SA: SerializerAdapter<D> = CDRSerial
   cc_upload: mio_channel::SyncSender<WriterCommand>,
   discovery_command: mio_channel::SyncSender<DiscoveryCommand>,
   status_receiver: StatusReceiver<DataWriterStatus>,
+  available_sequence_number: AtomicI64,
 }
 
 impl<D, SA> Drop for DataWriter<D, SA>
@@ -153,9 +222,24 @@ where
       cc_upload,
       discovery_command,
       status_receiver: StatusReceiver::new(status_receiver_rec),
+      available_sequence_number: AtomicI64::new(1), // valid numbering starts from 1
     })
   }
 
+  fn next_sequence_number(&self) -> SequenceNumber {
+    SequenceNumber::from(
+      self
+        .available_sequence_number
+        .fetch_add(1, Ordering::Relaxed),
+    )
+  }
+
+  fn undo_sequence_number(&self) {
+    self
+      .available_sequence_number
+      .fetch_sub(1, Ordering::Relaxed);
+  }
+
   // This one function provides both get_matched_subscrptions and
   // get_matched_subscription_data TODO: Maybe we could return references to the
   // subscription data to avoid copying? But then what if the result set changes
@@ -247,15 +331,22 @@ where
   /// data_writer.write(some_data, None).unwrap();
   /// ```
   pub fn write(&self, data: D, source_timestamp: Option<Timestamp>) -> Result<()> {
+    self.write_with_options(data, WriteOptions::from(source_timestamp))?;
+    Ok(())
+  }
+
+  pub fn write_with_options(&self, data: D, write_options: WriteOptions) -> Result<SampleIdentity> {
     let send_buffer = SA::to_bytes(&data)?; // serialize
 
     let ddsdata = DDSData::new(SerializedPayload::new_from_bytes(
       SA::output_encoding(),
       send_buffer,
     ));
+    let sequence_number = self.next_sequence_number();
     let writer_command = WriterCommand::DDSData {
       data: ddsdata,
-      source_timestamp,
+      write_options,
+      sequence_number,
     };
 
     let timeout = match self.qos().reliability() {
@@ -266,7 +357,10 @@ where
     match try_send_timeout(&self.cc_upload, writer_command, timeout) {
       Ok(_) => {
         self.refresh_manual_liveliness();
-        Ok(())
+        Ok(SampleIdentity {
+          writer_guid: self.my_guid,
+          sequence_number,
+        })
       }
       Err(e) => {
         warn!(
@@ -275,6 +369,7 @@ where
           e,
           timeout,
         );
+        self.undo_sequence_number();
         Err(Error::OutOfResources)
       }
     }
@@ -828,9 +923,13 @@ where
       .cc_upload
       .send(WriterCommand::DDSData {
         data: ddsdata,
-        source_timestamp,
+        write_options: WriteOptions::from(source_timestamp),
+        sequence_number: self.next_sequence_number(),
       })
-      .or_else(|huh| log_and_err_internal!("Cannot send dispose command: {:?}", huh))?;
+      .or_else(|huh| {
+        self.undo_sequence_number();
+        log_and_err_internal!("Cannot send dispose command: {:?}", huh)
+      })?;
 
     self.refresh_manual_liveliness();
     Ok(())
