@@ -22,6 +22,7 @@ use crate::{
     ddsdata::DDSData,
     dp_event_loop::{NACK_RESPONSE_DELAY, NACK_SUPPRESSION_DURATION},
     qos::HasQoSPolicy,
+    with_key::datawriter::WriteOptions,
   },
   messages::submessages::submessages::AckSubmessage,
   network::udp_sender::UDPSender,
@@ -179,7 +180,8 @@ pub(crate) struct Writer {
 pub(crate) enum WriterCommand {
   DDSData {
     data: DDSData,
-    source_timestamp: Option<Timestamp>,
+    write_options: WriteOptions,
+    sequence_number: SequenceNumber,
   },
   WaitForAcknowledgments {
     all_acked: mio_channel::SyncSender<()>,
@@ -379,7 +381,8 @@ impl Writer {
       match cc {
         WriterCommand::DDSData {
           data,
-          source_timestamp,
+          write_options,
+          sequence_number,
         } => {
           // We have a new sample here. Things to do:
           // 1. Insert it to history cache and get it sequence numbered
@@ -387,13 +390,14 @@ impl Writer {
           //    If we are pushing data, send the DATA submessage and HEARTBEAT.
           //    If we are not pushing, send out HEARTBEAT only. Readers will then ask the
           // DATA with ACKNACK.
-          let timestamp = self.insert_to_history_cache(data, source_timestamp);
+          let timestamp =
+            self.insert_to_history_cache(data, write_options.clone(), sequence_number);
 
           self.increase_heartbeat_counter();
 
           let partial_message = MessageBuilder::new();
           // If DataWriter sent us a source timestamp, then add that.
-          let partial_message = if let Some(src_ts) = source_timestamp {
+          let partial_message = if let Some(src_ts) = write_options.source_timestamp {
             partial_message.ts_msg(self.endianness, Some(src_ts))
           } else {
             partial_message
@@ -469,10 +473,11 @@ impl Writer {
   fn insert_to_history_cache(
     &mut self,
     data: DDSData,
-    source_timestamp: Option<Timestamp>,
+    write_options: WriteOptions,
+    sequence_number: SequenceNumber,
   ) -> Timestamp {
     // first increasing last SequenceNumber
-    let new_sequence_number = self.last_change_sequence_number + SequenceNumber::from(1);
+    let new_sequence_number = sequence_number;
     self.last_change_sequence_number = new_sequence_number;
 
     // setting first change sequence number according to our qos (not offering more
@@ -495,12 +500,7 @@ impl Writer {
     assert!(self.last_change_sequence_number > SequenceNumber::zero());
 
     // create new CacheChange from DDSData
-    let new_cache_change = CacheChange::new(
-      self.guid(),
-      self.last_change_sequence_number,
-      source_timestamp,
-      data,
-    );
+    let new_cache_change = CacheChange::new(self.guid(), new_sequence_number, write_options, data);
 
     // inserting to DDSCache
     // timestamp taken here is used as a unique(!) key in the DDSCache.
