@@ -1,10 +1,13 @@
-use crate::messages::validity_trait::Validity;
-use crate::messages::protocol_id::ProtocolId;
-use crate::messages::protocol_version::ProtocolVersion;
-use crate::messages::vendor_id::VendorId;
-use crate::structure::guid::GuidPrefix;
 use speedy::{Readable, Writable};
 
+use crate::{
+  messages::{
+    protocol_id::ProtocolId, protocol_version::ProtocolVersion, validity_trait::Validity,
+    vendor_id::VendorId,
+  },
+  structure::guid::GuidPrefix,
+};
+
 #[derive(Debug, Clone, Readable, Writable, PartialEq)]
 pub struct Header {
   pub protocol_id: ProtocolId,
@@ -27,7 +30,8 @@ impl Header {
 impl Validity for Header {
   fn valid(&self) -> bool {
     // Three validity rules from RTPS 2.3 spec section 8.3.6.3
-    // (1) We cannot reach this point if the message has too few bytes to contain a full header.
+    // (1) We cannot reach this point if the message has too few bytes to contain a
+    // full header.
     self.protocol_id == ProtocolId::PROTOCOL_RTPS // (2)
     && self.protocol_version.major <= ProtocolVersion::THIS_IMPLEMENTATION.major
     // (3)
@@ -40,7 +44,7 @@ mod tests {
 
   #[test]
   fn header_protocol_version_major() {
-    let mut header = Header::new(GuidPrefix::GUIDPREFIX_UNKNOWN);
+    let mut header = Header::new(GuidPrefix::UNKNOWN);
 
     header.protocol_version = ProtocolVersion::PROTOCOLVERSION_1_0;
     assert!(header.valid());
@@ -54,7 +58,7 @@ mod tests {
 
   #[test]
   fn header_protocol_id_same_as_rtps() {
-    let mut header = Header::new(GuidPrefix::GUIDPREFIX_UNKNOWN);
+    let mut header = Header::new(GuidPrefix::UNKNOWN);
 
     header.protocol_id = ProtocolId::PROTOCOL_RTPS;
     assert!(header.valid());
@@ -63,7 +67,7 @@ mod tests {
   serialization_test!( type = Header,
   {
       header_with_unknown_guid_prefix,
-      Header::new(GuidPrefix::GUIDPREFIX_UNKNOWN),
+      Header::new(GuidPrefix::UNKNOWN),
       le = [0x52, 0x54, 0x50, 0x53, // protocol_id
             0x02, 0x04,             // protocol_verison
             0x01, 0x12,             // vendor_id
