@@ -1,12 +1,12 @@
-use crate::{
-  serialization::SubMessage, serialization::SubmessageBody, structure::guid::EntityId,
-  messages::submessages::submessages::SubmessageHeader,
-};
-use crate::structure::sequence_number::SequenceNumberSet;
 use enumflags2::BitFlags;
 use log::error;
 use speedy::{Readable, Writable};
 
+use crate::{
+  messages::submessages::submessages::SubmessageHeader,
+  serialization::{SubMessage, SubmessageBody},
+  structure::{guid::EntityId, sequence_number::SequenceNumberSet},
+};
 use super::{
   submessage::EntitySubmessage, submessage_flag::ACKNACK_Flags, submessage_kind::SubmessageKind,
 };
@@ -76,8 +76,8 @@ mod tests {
   {
       acknack,
       AckNack {
-          reader_id: EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_READER,
-          writer_id: EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_WRITER,
+          reader_id: EntityId::SEDP_BUILTIN_PUBLICATIONS_READER,
+          writer_id: EntityId::SEDP_BUILTIN_PUBLICATIONS_WRITER,
           reader_sn_state: SequenceNumberSet::new_empty(SequenceNumber::from(0)),
           count: 1,
       },
