@@ -1,7 +1,7 @@
-use crate::structure::guid::EntityId;
-use crate::structure::sequence_number::*;
 use speedy::{Readable, Writable};
 
+use crate::structure::{guid::EntityId, sequence_number::*};
+
 /// The NackFrag Submessage is used to communicate the state of a Reader to a
 /// Writer. When a data change is sent as a series of fragments, the NackFrag
 /// Submessage allows the Reader to inform the Writer about specific fragment
@@ -44,8 +44,8 @@ mod tests {
   {
       nack_frag,
       NackFrag {
-          reader_id: EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_READER,
-          writer_id: EntityId::ENTITYID_SEDP_BUILTIN_PUBLICATIONS_WRITER,
+          reader_id: EntityId::SEDP_BUILTIN_PUBLICATIONS_READER,
+          writer_id: EntityId::SEDP_BUILTIN_PUBLICATIONS_WRITER,
           writer_sn: SequenceNumber::from(42),
           fragment_number_state: FragmentNumberSet::new_empty(FragmentNumber::from(1000u32)),
           count: 6,
