@@ -95,13 +95,9 @@ impl<'de> PlCdrDeserializer<'de> {
   fn custom_deserialize_any<V>(self, visitor: V) -> Result<V::Value>
   where
     V: serde::de::Visitor<'de>,
-    /*BuiltinDataDeserializer<LittleEndian, V::Value>: DataGeneration<V::Value>,
-     *BuiltinDataDeserializer<BigEndian, V::Value>: DataGeneration<V::Value>, */
   {
     match self.endianness {
       RepresentationIdentifier::PL_CDR_LE | RepresentationIdentifier::PL_CDR_BE => {
-        //let rep: Result<Vec<u8>> = to_bytes::<u16,
-        // LittleEndian>(&u16::from(self.endianness));
         visitor.visit_bytes(&[&self.endianness.to_bytes(), self.input].concat())
       }
       e => Err(Error::Message(format!("Unsupported endianness {:?}", e))),
